// By Sven Thommesen <sthomme@humsci.auburn.edu>
// "HumbugModelSwarm.m"

// Import Swarm libraries:

#import <math.h>
#import <space.h>
#import <activity.h>
#import <collections.h>
#import <objectbase.h>
#import <simtools.h>
#import <random.h>

#import "HumbugModelSwarm.h"

// HumbugModelSwarm.m:
// Simple informational output for each object 
// Usage: './humbug -b > runlog'


@implementation HumbugModelSwarm

+createBegin: (id) aZone {
  HumbugModelSwarm * obj;

  obj = [super createBegin: aZone];

  obj->debugPrint = 1;

  obj->myStream = [ OutputStream create: aZone setFileStream: stdout ];

  return obj;
}

-createEnd {
  return [super createEnd];
}

-buildObjects {
  unsigned int mySeeds[1024];
  int i,j;
  id myGen1, myGen2, myGen3, myGen4, myGen5;
 
  [super buildObjects];

// SIMPLE generators:

// -----
  // myGen = [SWB1gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [SWB1gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [SWB1gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [SWB1gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [SWB2gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [SWB2gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [SWB2gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [SWB2gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [SWB3gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [SWB3gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [SWB3gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [SWB3gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [PMMLCG1gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [PMMLCG1gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [PMMLCG1gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [PMMLCG1gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [PMMLCG2gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [PMMLCG2gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [PMMLCG2gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [PMMLCG2gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [PMMLCG3gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [PMMLCG3gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [PMMLCG3gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [PMMLCG3gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [PMMLCG4gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [PMMLCG4gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [PMMLCG4gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [PMMLCG4gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [PMMLCG5gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [PMMLCG5gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [PMMLCG5gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [PMMLCG5gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [PMMLCG6gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [PMMLCG6gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [PMMLCG6gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [PMMLCG6gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [PMMLCG7gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [PMMLCG7gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [PMMLCG7gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [PMMLCG7gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [PMMLCG8gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [PMMLCG8gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [PMMLCG8gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [PMMLCG8gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [PMMLCG9gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [PMMLCG9gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [PMMLCG9gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [PMMLCG9gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [LCG1gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [LCG1gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [LCG1gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [LCG1gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [LCG2gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [LCG2gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [LCG2gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [LCG2gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [LCG3gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [LCG3gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [LCG3gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [LCG3gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [ACGgen create: [self getZone] setStateFromSeed: 1];
  // myGen = [ACGgen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [ACGgen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [ACGgen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [SCGgen create: [self getZone] setStateFromSeed: 1];
  // myGen = [SCGgen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [SCGgen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [SCGgen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [PSWBgen create: [self getZone] setStateFromSeed: 1];
  // myGen = [PSWBgen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [PSWBgen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [PSWBgen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [MRG5gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [MRG5gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [MRG5gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [MRG5gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [MRG6gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [MRG6gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [MRG6gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [MRG6gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [MRG7gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [MRG7gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [MRG7gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [MRG7gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [C2MRG3gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [C2MRG3gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [C2MRG3gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [C2MRG3gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [C2TAUS1gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [C2TAUS1gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [C2TAUS1gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [C2TAUS1gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [C2TAUS2gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [C2TAUS2gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [C2TAUS2gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [C2TAUS2gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [C2TAUS3gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [C2TAUS3gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [C2TAUS3gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [C2TAUS3gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [TT403gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [TT403gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [TT403gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [TT403gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [TT775gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [TT775gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [TT775gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [TT775gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [TT800gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [TT800gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [TT800gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [TT800gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [MT19937gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [MT19937gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [MT19937gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [MT19937gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [MWCAgen create: [self getZone] setStateFromSeed: 1];
  // myGen = [MWCAgen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [MWCAgen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [MWCAgen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [MWCBgen create: [self getZone] setStateFromSeed: 1];
  // myGen = [MWCBgen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [MWCBgen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [MWCBgen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [C3MWCgen create: [self getZone] setStateFromSeed: 1];
  // myGen = [C3MWCgen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [C3MWCgen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [C3MWCgen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [RWC2gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [RWC2gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [RWC2gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [RWC2gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----
  // myGen = [RWC8gen create: [self getZone] setStateFromSeed: 1];
  // myGen = [RWC8gen create: [self getZone] setStateFromSeed: RANDOMSEED];
  // myGen = [RWC8gen create: [self getZone] setStateFromSeeds: mySeeds];
  myGen = [RWC8gen createWithDefaults: [self getZone]];
  [myGen describe: myStream];
  [myGen drop];
// -----

// SPLIT generators:

// -----
  // myGen = [C2LCGXgen create: [self getZone] 
  // 		setA: 32 setv: 20 setw: 30
  // 		setStateFromSeed: 1];
  // myGen = [C2LCGXgen create: [self getZone] 
  // 		setA: 32 setv: 20 setw: 30
  // 		setStateFromSeed: RANDOMSEED];
  // myGen = [C2LCGXgen create: [self getZone] 
  // 		setA: 32 setv: 20 setw: 30
  // 		setStateFromSeeds: mySeeds];
  mySplitGen = [C2LCGXgen createWithDefaults: [self getZone]];
  [mySplitGen describe: myStream];
  [mySplitGen drop];
// -----
  // myGen = [C4LCGXgen create: [self getZone] 
  // 		setA: 128 setv: 31 setw: 41
  // 		setStateFromSeed: 1];
  // myGen = [C4LCGXgen create: [self getZone] 
  // 		setA: 128 setv: 31 setw: 41
  // 		setStateFromSeed: RANDOMSEED];
  // myGen = [C4LCGXgen create: [self getZone] 
  // 		setA: 128 setv: 31 setw: 41
  // 		setStateFromSeeds: mySeeds];
  mySplitGen = [C4LCGXgen createWithDefaults: [self getZone]];
  [mySplitGen describe: myStream];
  [mySplitGen drop];
// -----

   mySimpleGen = [PMMLCG1gen createWithDefaults: [self getZone]];
   mySplitGen  = [C4LCGXgen  createWithDefaults: [self getZone]];

// DISTRIBUTIONS:

// -----
  randomBitDist = [RandomBitDist createWithDefaults: [self getZone]];
  // myDist = [RandomBitDist create: [self getZone] setGenerator: mySimpleGen];
  // myDist = [RandomBitDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8];
  [randomBitDist describe: myStream];
  [randomBitDist drop];
// -----
  bernoulliDist = [BernoulliDist createWithDefaults: [self getZone]];
  // myDist = [BernoulliDist create: [self getZone] setGenerator: mySimpleGen];
  // myDist = [BernoulliDist create: [self getZone] setGenerator: mySimpleGen
  //		setProbability: 0.67];
  // myDist = [BernoulliDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8];
  // myDist = [BernoulliDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8
  // 		setProbability: 0.67];
  [bernoulliDist describe: myStream];
  [bernoulliDist drop];
// -----
  uniformIntegerDist = [UniformIntegerDist createWithDefaults: [self getZone]];
  // myDist = [UniformIntegerDist create: [self getZone] 
  // 		setGenerator: mySimpleGen];
  // myDist = [UniformIntegerDist create: [self getZone] 
  //		setGenerator: mySimpleGen
  //		setIntegerMin: -33 setMax: 78 ];
  // myDist = [UniformIntegerDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8];
  // myDist = [UniformIntegerDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8
  // 		setIntegerMin: -33 setMax: 78 ];
  [uniformIntegerDist describe: myStream];
  [uniformIntegerDist drop];
// -----
uniformUnsignedDist = [UniformUnsignedDist createWithDefaults: [self getZone]];
  // myDist = [UniformUnsignedDist create: [self getZone] 
  // 		setGenerator: mySimpleGen];
  // myDist = [UniformUnsignedDist create: [self getZone] 
  //		setGenerator: mySimpleGen
  //		setUnsignedMin: 28 setMax: 61 ];
  // myDist = [UniformUnsignedDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8];
  // myDist = [UniformUnsignedDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8
  // 		setUnsignedMin: 28 setMax: 61 ];
  [uniformUnsignedDist describe: myStream];
  [uniformUnsignedDist drop];
// -----
  uniformDoubleDist = [UniformDoubleDist createWithDefaults: [self getZone]];
  // myDist = [UniformDoubleDist create: [self getZone] 
  // 		setGenerator: mySimpleGen];
  // myDist = [UniformDoubleDist create: [self getZone] 
  //		setGenerator: mySimpleGen
  //		setDoubleMin: 3.14159 setMax: 2.81218 ];
  // myDist = [UniformDoubleDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8];
  // myDist = [UniformDoubleDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8
  // 		setDoubleMin: 3.14159 setMax: 2.81218 ];
  [uniformDoubleDist describe: myStream];
  [uniformDoubleDist drop];
// -----
  normalDist = [NormalDist createWithDefaults: [self getZone]];
  // myDist = [NormalDist create: [self getZone] setGenerator: mySimpleGen];
  // myDist = [NormalDist create: [self getZone] setGenerator: mySimpleGen
  //		setMean: 3.0 setVariance: 1.5 ];
  // myDist = [NormalDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8];
  // myDist = [NormalDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8
  // 		setMean: 3.0 setVariance: 1.5];
  [normalDist describe: myStream];
  [normalDist drop];
// -----
  logNormalDist = [LogNormalDist createWithDefaults: [self getZone]];
  // myDist = [LogNormalDist create: [self getZone] setGenerator: mySimpleGen];
  // myDist = [LogNormalDist create: [self getZone] setGenerator: mySimpleGen
  //		setMean: 3.0 setVariance: 1.5 ];
  // myDist = [LogNormalDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8];
  // myDist = [LogNormalDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8
  // 		setMean: 3.0 setVariance: 1.5];
  [logNormalDist describe: myStream];
  [logNormalDist drop];
// -----
  exponentialDist = [ExponentialDist createWithDefaults: [self getZone]];
 // myDist = [ExponentialDist create: [self getZone] setGenerator: mySimpleGen];
 // myDist = [ExponentialDist create: [self getZone] setGenerator: mySimpleGen
 //		setMean: 3.0 ];
 // myDist = [ExponentialDist create: [self getZone]
 // 		setGenerator: mySplitGen setVirtualGenerator: 8];
 // myDist = [ExponentialDist create: [self getZone]
 // 		setGenerator: mySplitGen setVirtualGenerator: 8
 // 		setMean: 3.0 ];
  [exponentialDist describe: myStream];
  [exponentialDist drop];
// -----
  gammaDist = [GammaDist createWithDefaults: [self getZone]];
  // myDist = [GammaDist create: [self getZone] setGenerator: mySimpleGen];
  // myDist = [GammaDist create: [self getZone] setGenerator: mySimpleGen
  // 		setAlpha: 3.0 setBeta: 1.5 ];
  // myDist = [GammaDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8];
  // myDist = [GammaDist create: [self getZone]
  // 		setGenerator: mySplitGen setVirtualGenerator: 8
  // 		setAlpha: 3.0 setBeta: 1.5 ];
  [gammaDist describe: myStream];
  [gammaDist drop];
// -----

  return self;
}

-buildActions {

  [super buildActions];

  return self;
}

-activateIn: (id) swarmContext {

  [super activateIn: swarmContext];

  return [self getSwarmActivity];
}

@end
